#
# spec file for package ghc-time-manager
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name time-manager
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        0.2.3
Release:        1.1
Summary:        Scalable timer
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-auto-update-devel
BuildRequires:  ghc-auto-update-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-stm-prof
ExcludeArch:    %{ix86}

%description
Scalable timer functions provided by a timer manager and thread management
functions to prevent thread leak by a thread manager.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun May 18 2025 Peter Simons <psimons@suse.com>
- Update time-manager to version 0.2.3.
  [#]# 0.2.3
  * Exporting defaultManager.
* Wed Dec 18 2024 Peter Simons <psimons@suse.com>
- Update time-manager to version 0.2.2.
  [#]# 0.2.2
  * `initialize` with non positive integer creates a time manager
    which does not maintain timeout.
    [#1017](https://github.com/yesodweb/wai/pull/1017)
* Fri Dec  6 2024 Peter Simons <psimons@suse.com>
- Update time-manager to version 0.2.1.
  [#]# 0.2.1
  * Export KilledByThreadManager exception
    [#1016](https://github.com/yesodweb/wai/pull/1016)
  [#]# 0.2.0
  * Providing `System.ThreadManager`.
  * `withHandle` catches `TimeoutThread` internally.
    It returns `Nothing` on timeout.
* Fri Nov 22 2024 Peter Simons <psimons@suse.com>
- Update time-manager to version 0.1.3.
  [#]# 0.1.3
  * Providing `withHandle` and `withHandleKillThread`.
* Tue Nov 19 2024 Peter Simons <psimons@suse.com>
- Update time-manager to version 0.1.2.
  [#]# 0.1.2
  * Holding `Weak ThreadId` to prevent thread leak again
    [#1013](https://github.com/yesodweb/wai/pull/1013)
* Thu Nov  7 2024 Peter Simons <psimons@suse.com>
- Update time-manager to version 0.1.1.
  [#]# 0.1.1
  * Removing `unliftio`.
* Sat Apr 27 2024 Peter Simons <psimons@suse.com>
- Update time-manager to version 0.1.0.
  Upstream added a new change log file in this release. With no
  previous version to compare against, the automatic updater cannot
  reliable determine the relevante entries for this release.
* Thu Aug 17 2023 Peter Simons <psimons@suse.com>
- Update time-manager to version 0.0.1.
  Upstream does not provide a change log file.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Nov  1 2022 Peter Simons <psimons@suse.com>
- Update time-manager to version 0.0.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add time-manager at version 0.0.0.
